@@ -1,5 +1,5 @@
-START: str = "Starting {!r}!"
-FINISH: str = "Elapsed time: {:0.4f} seconds. Finished {!r}"
+START: str = "Starting {!r} in thread {}."
+FINISH: str = "Elapsed time: {:0.4f} seconds. Finished {!r} in thread {}."
 CONTEXT: str = "ContextManager"
 
 EXCEPTION: str = "An exception '{}' occurred, with message '{}'. Traceback is in debug log. Finished {!r}."
